import json
import ssl
import requests
from logan import exceptions
from requests.adapters import HTTPAdapter
from requests.auth import HTTPBasicAuth 

class LoganAPI(object):
    
    base_url = "http://gobbler.labs.hashedin.com/api/v0"
    events_url = "%s/events" % base_url
    
    def __init__(self, access_token,project_id, silent=False, base_url=None, events_url=None, conn_timeout=4, read_timeout=5):
        self.conn_timeout = conn_timeout
        self.read_timeout = read_timeout
        self.project_id = project_id
        self.silent = silent
        if base_url:
            self.base_url = base_url
        if events_url:
            self.events_url = events_url
        self.auth = HTTPBasicAuth(access_token, 'u')
        self.session = self._create_session()

    def _create_session(self):

        """ Build a session that uses KeenAdapter for SSL """

        s = requests.Session()
        a = requests.adapters.HTTPAdapter(pool_connections=10, 
                                            pool_maxsize=10,
                                            pool_block=False
                                            )
        s.mount('https://', a)
        s.mount('http://', a)
        return s

    def post_event(self, event_name, event=None):
        if not event:
            event = {}
        to_send = {}
        to_send['name'] = event_name
        to_send['projectId'] = self.project_id
        to_send["eventData"] = event
        try :
            return self._post_event_internal(to_send)
        except Exception as e:
            if self.silent:
                return None
            else:
                raise


    def _post_event_internal(self, event):
        headers = {"Content-Type": "application/json"}
        payload = json.dumps(event)
        response = self.session.post(self.events_url, auth=self.auth, 
            data=payload, headers=headers, 
            timeout=(self.conn_timeout, self.read_timeout)
            )
        if response.status_code != 201:
            error = response.json()
            raise exceptions.LoganError(error)
